#!/bin/bash

user_input=
maf=0
genome_mode=1
input_format=
output_format=vcf
nc_mode=0

function usage 
{
	echo " 
      * * * * * * * * * * * * * * * * * *
      *		FunSEQ version 0.1      *
      *		    May, 2013           *
      *	     funseq.gersteinlab.org     *
      * * * * * * * * * * * * * * * * * *

	* Output directory : out/
	
1. Usage : ./funseq -f file -maf maf -m <1/2> -inf <bed/vcf> -outf <bed/vcf> -nc 
	Options : 
			-f		user input SNVs file
			-maf 		minor allele frequency (MAF) threshold to filter 1KG phaseI SNVs (value 0 ~ 1)
			-m		1 - Somatic Genome; 2 - Germline or Personal Genome
			-inf	 	input format - BED or VCF
			-outf	 	output format - BED or VCF
			-nc		[Optional] Only do analysis on non-coding variants; No need to install vat

	Default : -maf 0 -m 1 -outf vcf 

	
2. Usage : multiple genomes with 'recurrent' output  (parallel running)
	Separate multiple files by ','
	example : ./funseq -f file1,file2,file3,... -maf 0 -m 1 -inf bed -outf vcf
	* NOTE: Please make sure you have sufficient number of CPU processors 

"
}


if [ -e $1 ];then
usage
exit
fi


while [ "$1" != "" ]; do
    case $1 in
        -f | --file )           shift
                                user_input=$1
                                ;;
	-maf)			shift
				maf=$1
				;;
	-m | --mode)		shift
				genome_mode=$1
				;;
	-inf)			shift
				input_format=$1
				;;
	-outf)			shift
				output_format=$1
				;;
	-nc)			nc_mode=1
				;;
       	-h | --help )		usage
				exit
				
	esac
        shift
done

if [[ $user_input != "" &&  $maf != ""  &&  $genome_mode != ""  &&  $input_format != ""  &&  $output_format  != "" ]]; then
	perl scripts/funseq.pl $user_input $maf $genome_mode $input_format $output_format $nc_mode
else
	echo "Please specify all paramters"
fi 
